@@ -47,9 +47,11 @@ MAX_POST_SIZE = 64 * 1024  # 64k Max post size
 MIN_FILE_SIZE = 256
 
 SKIP_SNIPPET_EXT = {  # File extensions to ignore snippets for
-                ".exe", ".zip", ".tar", ".tgz", ".gz", ".rar", ".jar", ".war", ".ear", ".class", ".pyc", ".o", ".a",
-                ".so", ".obj", ".dll", ".lib", ".out", ".app",
-                ".doc", ".docx", ".xls", ".xlsx", ".ppt"
+                ".exe", ".zip", ".tar", ".tgz", ".gz", ".7z", ".rar", ".jar", ".war", ".ear", ".class", ".pyc",
+                ".o", ".a", ".so", ".obj", ".dll", ".lib", ".out", ".app", ".bin",
+                ".lst", ".dat", ".json", ".htm", ".html", ".xml",
+                ".doc", ".docx", ".xls", ".xlsx", ".ppt", ".pptx", ".odt", ".ods", ".odp", ".pages", ".key", ".numbers",
+                ".pdf"
 }
 
 class Winnowing:
@@ -95,7 +97,9 @@ class Winnowing:
     a list of WFP fingerprints with their corresponding line numbers.
     """
 
-    def __init__(self, size_limit: bool = True, debug: bool = False, trace: bool = False, quiet: bool = False):
+    def __init__(self, size_limit: bool = True, debug: bool = False, trace: bool = False, quiet: bool = False,
+                 skip_snippets: bool = False, post_size: int = 64
+                 ):
         """
         Instantiate Winnowing class
         Parameters
@@ -103,10 +107,12 @@ class Winnowing:
             size_limit: bool
                 Limit the size of a fingerprint to 64k (post size) - Default True
         """
-        self.size_limit = size_limit
-        self.debug = debug
-        self.trace = trace
-        self.quiet = quiet
+        self.size_limit    = size_limit
+        self.debug         = debug
+        self.trace         = trace
+        self.quiet         = quiet
+        self.skip_snippets = skip_snippets
+        self.max_post_size = post_size * 1024 if post_size > 0 else MAX_POST_SIZE
 
     @staticmethod
     def __normalize(byte):
@@ -210,8 +216,8 @@ class Winnowing:
         # Print file line
         content_length = len(contents)
         wfp = 'file={0},{1},{2}\n'.format(file_md5, content_length, file)
-        # We don't process snippets for binaries.
-        if bin_file or self.__skip_snippets(file, contents.decode('utf-8', 'ignore')):
+        # We don't process snippets for binaries, or other uninteresting files, or if we're requested to skip
+        if bin_file or self.skip_snippets or self.__skip_snippets(file, contents.decode('utf-8', 'ignore')):
             return wfp
         # Initialize variables
         gram = ""
@@ -248,7 +254,7 @@ class Winnowing:
                             if last_line != line:
                                 if output:
                                     if self.size_limit and \
-                                            (len(wfp.encode("utf-8")) + len(output.encode("utf-8"))) > MAX_POST_SIZE:
+                                            (len(wfp.encode("utf-8")) + len(output.encode("utf-8"))) > self.max_post_size:
                                         self.print_debug(f'Truncating WFP (64k limit) for: {file}')
                                         output = ''
                                         break               # Stop collecting snippets as it's over 64k
@@ -263,7 +269,7 @@ class Winnowing:
                         window.pop(0)
                     # Shift gram
                     gram = gram[1:]
-        if output and (not self.size_limit or (len(wfp.encode("utf-8")) + len(output.encode("utf-8"))) < MAX_POST_SIZE):
+        if output and (not self.size_limit or (len(wfp.encode("utf-8")) + len(output.encode("utf-8"))) < self.max_post_size):
             wfp += output + '\n'
 
         return wfp
